PrintRow class

Constructors

PrintRow({String? text, int? fontSize, int? position})
PrintRow.fromJson(Map<String, dynamic> json)

Properties

fontSize ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
position ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited